<?php

global $newproject_text;
$newproject_text = array (

'createnewproject'	=>	'Create a new Project',
'projecttitle'		=>	'Project Title',
'themestyle'		=>	'Theme / Style',
'projectprefs'		=>	'Project Preferences',
'defaultproject'	=>	'Default Project',
'projectlists'		=>	'Project lists',
'addnewproject'		=>	'Add New Project',
'showlogo'			=>	'Show title logo image',
'intromessage'		=>	'Introductory message',
'htmlallowed'		=>	'HTML code is allowed',
'createproject'		=>	'Create a new Project',
'noone'				=>	'No-one',
'defaultcatowner'	=>	'Default Category Owner',
'createthisproject'	=>	'Create this project',
'nopermission'		=>	'You don\'t have permission to use this page',

// Added in version 0.9.6
'inlineimages'		=>	'Show image attachments inline',

// Added in version 0.9.7
'othersview'		=>	'Allow anyone to view this project',
'allowanonopentask'     =>      'Allow anonymous users to open tasks',

);
?>
